# PyRoll Marini Spreading

Plugin for PyRoll providing the Marini spreading model

For the docs, see [here](docs/docs.pdf).

This project is licensed under the [BSD-3-Clause license](LICENSE).

The package is available via [PyPi](https://pypi.org/project/pyroll-marini-spreading/) and can be installed with
    
    pip install pyroll-marini-spreading
